<?php
/*
	Plugin Name: UBN Private content
	Description:  Display private post content only to users of a specific role.
	Plugin URI: http://www.aldolat.it/
	Author: Aldo Latino
	Author URI: http://www.aldolat.it/
	Version: 0.1
*/

/*
	Copyright (C) 2009, 2010  Aldo Latino  (email : aldolat@gmail.com)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

    Thanks to:
    Jeff Starr ( http://digwp.com/2010/05/private-content-posts-shortcode ) and
    Jean Baptiste Jung ( http://www.wprecipes.com/add-private-notes-to-your-wordpress-blog-posts )
    for the idea and starting code.
*/

/**
 * ubn_private_content($atts, $content = null)
 *
 * Shortcode to display private post content only to users of a specific role.
 *
 * Usage:
 *
 * [private role="administrator"]Text for administrators[/private]
 * [private role="editor"]Text for editors[/private]
 * [private role="editor-only"]Text for editors only[/private]
 * [private role="author"]Text for authors[/private]
 * [private role="author-only"]Text for authors only[/private]
 * [private role="contributor"]Text for contributor[/private]
 * [private role="contributor-only"]Text for contributors only[/private]
 * [private role="subscriber"]Text for subscribers[/private]
 * [private role="subscriber-only"]Text for subscribers only[/private]
 *
 * Unless you use the *-only role, an administrator can read an editor private content,
 * a subscriber private content, and so on.
 * Same thing for editor, author, contributor, and subscriber: a higher role can read a lower content.
 * If you use, for example, subcriber-only, an administrator cannot read the content.
 *
 * WordPress Roles in descending order:
 * Administrator,
 * Editor,
 * Author,
 * Contributor,
 * Subscriber.
 *
*/
function ubn_private_content($atts, $content = null) {
	extract(shortcode_atts(array(
		'role' => ''
	), $atts));
	switch ($role) {
		case 'administrator' :
			if (current_user_can('administrator')) {
				$output = '<p class="private administrator-content">'.$content.'</p>';
			}
		break;
		case 'editor' :
			if (current_user_can('administrator') || current_user_can('editor')) {
				$output = '<p class="private editor-content">'.$content.'</p>';
			}
		break;
		case 'editor-only' :
			if (current_user_can('editor')) {
				$output = '<p class="private editor-content">'.$content.'</p>';
			}
		break;
		case 'author' :
			if (current_user_can('administrator') || current_user_can('editor') || current_user_can('author')) {
				$output = '<p class="private author-content">'.$content.'</p>';
			}
		break;
		case 'author-only' :
			if (current_user_can('author')) {
				$output = '<p class="private author-content">'.$content.'</p>';
			}
		break;
		case 'contributor' :
			if (current_user_can('administrator') || current_user_can('editor') || current_user_can('author') || current_user_can('contributor')) {
				$output = '<p class="private contributor-content">'.$content.'</p>';
			}
		break;
		case 'contributor-only' :
			if (current_user_can('contributor')) {
				$output = '<p class="private contributor-content">'.$content.'</p>';
			}
		break;
		case 'subscriber' :
			if (current_user_can('administrator') || current_user_can('editor') || current_user_can('author') || current_user_can('contributor') || current_user_can('subscriber')) {
				$output = '<p class="private subscriber-content">'.$content.'</p>';
			}
		break;
		case 'subscriber-only' :
			if (current_user_can('subscriber')) {
				$output = '<p class="private subscriber-content">'.$content.'</p>';
			}
		break;
	}
	return $output;
}
add_shortcode('private', 'ubn_private_content');
?>